package cn.com.infosec.crypto.params;

import cn.com.infosec.crypto.KeyGenerationParameters;
import java.security.SecureRandom;

public class NaccacheSternKeyGenerationParameters extends KeyGenerationParameters {
   private int certainty;
   private int cntSmallPrimes;
   private boolean debug;

   public NaccacheSternKeyGenerationParameters(SecureRandom random, int strength, int certainty, int cntSmallPrimes) {
      this(random, strength, certainty, cntSmallPrimes, false);
   }

   public NaccacheSternKeyGenerationParameters(SecureRandom random, int strength, int certainty, int cntSmallPrimes, boolean debug) {
      super(random, strength);
      this.debug = false;
      this.certainty = certainty;
      if (cntSmallPrimes % 2 != 1) {
         if (cntSmallPrimes >= 30) {
            this.cntSmallPrimes = cntSmallPrimes;
            this.debug = debug;
         } else {
            throw new IllegalArgumentException("cntSmallPrimes must be >= 30 for security reasons");
         }
      } else {
         throw new IllegalArgumentException("cntSmallPrimes must be a multiple of 2");
      }
   }

   public int getCertainty() {
      return this.certainty;
   }

   public int getCntSmallPrimes() {
      return this.cntSmallPrimes;
   }

   public boolean isDebug() {
      return this.debug;
   }
}
